@@ -9,19 +9,19 @@
  fee is hereby granted, provided that the above copyright
  notice appear in all copies and that both that copyright
  notice and this permission notice appear in supporting
- documentation, and that the name of Silicon Graphics not be 
- used in advertising or publicity pertaining to distribution 
+ documentation, and that the name of Silicon Graphics not be
+ used in advertising or publicity pertaining to distribution
  of the software without specific prior written permission.
- Silicon Graphics makes no representation about the suitability 
+ Silicon Graphics makes no representation about the suitability
  of this software for any purpose. It is provided "as is"
  without any express or implied warranty.
- 
- SILICON GRAPHICS DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS 
- SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY 
+
+ SILICON GRAPHICS DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS
+ SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
  AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL SILICON
- GRAPHICS BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL 
- DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, 
- DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE 
+ GRAPHICS BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
+ DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
+ DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
  OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION  WITH
  THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
@@ -39,7 +39,6 @@
 	{ _XkbErrCode= (c); _XkbErrLocation= (l); _XkbErrData= (d); }
 #endif
 
-#ifndef XKB_IN_SERVER
 
 #define	_XkbAlloc(s)		malloc((s))
 #define	_XkbCalloc(n,s)		calloc((n),(s))
@@ -59,12 +58,11 @@
 #endif
 #endif
 
-#endif
 
 _XFUNCPROTOBEGIN
 
-static inline
-char *_XkbDupString(const char *s)
+static inline char *
+_XkbDupString(const char *s)
 {
     return s ? strdup(s) : NULL;
 }
@@ -75,8 +73,8 @@ char *_XkbDupString(const char *s)
 extern int _XkbStrCaseCmp(char *s1, char *s2);
 #else
 #define _XkbStrCaseCmp strcasecmp
+#include <strings.h>
 #endif
 
 _XFUNCPROTOEND
-
-#endif /* _XKBFILEINT_H_ */
+#endif                          /* _XKBFILEINT_H_ */
